package paulscode.sound.libraries;

import java.nio.ByteBuffer;
import java.nio.IntBuffer;
import java.util.LinkedList;
import javax.sound.sampled.AudioFormat;
import org.lwjgl.BufferUtils;
import org.lwjgl.openal.AL10;
import paulscode.sound.Channel;

/* loaded from: paulscode_sound_libraries.jar:paulscode/sound/libraries/ChannelLWJGLOpenAL.class */
public class ChannelLWJGLOpenAL extends Channel {
    public IntBuffer ALSource;
    public int ALformat;
    public int sampleRate;
    ByteBuffer bufferBuffer;

    public ChannelLWJGLOpenAL(int i, IntBuffer intBuffer) {
        super(i);
        this.bufferBuffer = BufferUtils.createByteBuffer(5242880);
        this.libraryType = LibraryLWJGLOpenAL.class;
        this.ALSource = intBuffer;
    }

    public void cleanup() {
        if (this.ALSource != null) {
            try {
                AL10.alSourceStop(this.ALSource);
                AL10.alGetError();
            } catch (Exception e) {
            }
            try {
                AL10.alDeleteSources(this.ALSource);
                AL10.alGetError();
            } catch (Exception e2) {
            }
            this.ALSource.clear();
        }
        this.ALSource = null;
        super.cleanup();
    }

    public boolean attachBuffer(IntBuffer intBuffer) {
        if (errorCheck(this.channelType != 0, "Sound buffers may only be attached to normal sources.")) {
            return false;
        }
        AL10.alSourcei(this.ALSource.get(0), 4105, intBuffer.get(0));
        return checkALError();
    }

    public void setAudioFormat(AudioFormat audioFormat) {
        int i;
        if (audioFormat.getChannels() == 1) {
            if (audioFormat.getSampleSizeInBits() == 8) {
                i = 4352;
            } else if (audioFormat.getSampleSizeInBits() == 16) {
                i = 4353;
            } else {
                errorMessage("Illegal sample size in method 'setAudioFormat'");
                return;
            }
        } else if (audioFormat.getChannels() == 2) {
            if (audioFormat.getSampleSizeInBits() == 8) {
                i = 4354;
            } else if (audioFormat.getSampleSizeInBits() == 16) {
                i = 4355;
            } else {
                errorMessage("Illegal sample size in method 'setAudioFormat'");
                return;
            }
        } else {
            errorMessage("Audio data neither mono nor stereo in method 'setAudioFormat'");
            return;
        }
        this.ALformat = i;
        this.sampleRate = (int) audioFormat.getSampleRate();
    }

    public void setFormat(int i, int i2) {
        this.ALformat = i;
        this.sampleRate = i2;
    }

    public boolean preLoadBuffers(LinkedList linkedList) {
        if (errorCheck(this.channelType != 1, "Buffers may only be queued for streaming sources.")) {
            return false;
        }
        if (errorCheck(linkedList == null, "Buffer List null in method 'preLoadBuffers'")) {
            return false;
        }
        boolean playing = playing();
        if (playing) {
            AL10.alSourceStop(this.ALSource.get(0));
            checkALError();
        }
        int alGetSourcei = AL10.alGetSourcei(this.ALSource.get(0), 4118);
        if (alGetSourcei > 0) {
            IntBuffer createIntBuffer = BufferUtils.createIntBuffer(alGetSourcei);
            AL10.alGenBuffers(createIntBuffer);
            if (errorCheck(checkALError(), "Error clearing stream buffers in method 'preLoadBuffers'")) {
                return false;
            }
            AL10.alSourceUnqueueBuffers(this.ALSource.get(0), createIntBuffer);
            if (errorCheck(checkALError(), "Error unqueuing stream buffers in method 'preLoadBuffers'")) {
                return false;
            }
        }
        if (playing) {
            AL10.alSourcePlay(this.ALSource.get(0));
            checkALError();
        }
        IntBuffer createIntBuffer2 = BufferUtils.createIntBuffer(linkedList.size());
        AL10.alGenBuffers(createIntBuffer2);
        if (errorCheck(checkALError(), "Error generating stream buffers in method 'preLoadBuffers'")) {
            return false;
        }
        for (int i = 0; i < linkedList.size(); i++) {
            this.bufferBuffer.clear();
            this.bufferBuffer.put((byte[]) linkedList.get(i), 0, ((byte[]) linkedList.get(i)).length);
            this.bufferBuffer.flip();
            try {
                AL10.alBufferData(createIntBuffer2.get(i), this.ALformat, this.bufferBuffer, this.sampleRate);
                if (errorCheck(checkALError(), "Error creating buffers in method 'preLoadBuffers'")) {
                    return false;
                }
            } catch (Exception e) {
                errorMessage("Error creating buffers in method 'preLoadBuffers'");
                printStackTrace(e);
                return false;
            }
        }
        try {
            AL10.alSourceQueueBuffers(this.ALSource.get(0), createIntBuffer2);
            if (errorCheck(checkALError(), "Error queuing buffers in method 'preLoadBuffers'")) {
                return false;
            }
            AL10.alSourcePlay(this.ALSource.get(0));
            if (errorCheck(checkALError(), "Error playing source in method 'preLoadBuffers'")) {
                return false;
            }
            return true;
        } catch (Exception e2) {
            errorMessage("Error queuing buffers in method 'preLoadBuffers'");
            printStackTrace(e2);
            return false;
        }
    }

    public boolean queueBuffer(byte[] bArr) {
        if (errorCheck(this.channelType != 1, "Buffers may only be queued for streaming sources.")) {
            return false;
        }
        this.bufferBuffer.clear();
        this.bufferBuffer.put(bArr, 0, bArr.length);
        this.bufferBuffer.flip();
        IntBuffer createIntBuffer = BufferUtils.createIntBuffer(1);
        AL10.alSourceUnqueueBuffers(this.ALSource.get(0), createIntBuffer);
        if (checkALError()) {
            return false;
        }
        AL10.alBufferData(createIntBuffer.get(0), this.ALformat, this.bufferBuffer, this.sampleRate);
        if (checkALError()) {
            return false;
        }
        AL10.alSourceQueueBuffers(this.ALSource.get(0), createIntBuffer);
        if (checkALError()) {
            return false;
        }
        return true;
    }

    public int feedRawAudioData(byte[] bArr) {
        IntBuffer createIntBuffer;
        if (errorCheck(this.channelType != 1, "Raw audio data can only be fed to streaming sources.")) {
            return -1;
        }
        ByteBuffer wrap = ByteBuffer.wrap(bArr, 0, bArr.length);
        int alGetSourcei = AL10.alGetSourcei(this.ALSource.get(0), 4118);
        if (alGetSourcei > 0) {
            createIntBuffer = BufferUtils.createIntBuffer(alGetSourcei);
            AL10.alGenBuffers(createIntBuffer);
            if (errorCheck(checkALError(), "Error clearing stream buffers in method 'feedRawAudioData'")) {
                return -1;
            }
            AL10.alSourceUnqueueBuffers(this.ALSource.get(0), createIntBuffer);
            if (errorCheck(checkALError(), "Error unqueuing stream buffers in method 'feedRawAudioData'")) {
                return -1;
            }
        } else {
            createIntBuffer = BufferUtils.createIntBuffer(1);
            AL10.alGenBuffers(createIntBuffer);
            if (errorCheck(checkALError(), "Error generating stream buffers in method 'preLoadBuffers'")) {
                return -1;
            }
        }
        AL10.alBufferData(createIntBuffer.get(0), this.ALformat, wrap, this.sampleRate);
        if (checkALError()) {
            return -1;
        }
        AL10.alSourceQueueBuffers(this.ALSource.get(0), createIntBuffer);
        if (checkALError()) {
            return -1;
        }
        if (this.attachedSource != null && this.attachedSource.channel == this && this.attachedSource.active() && !playing()) {
            AL10.alSourcePlay(this.ALSource.get(0));
            checkALError();
        }
        return alGetSourcei;
    }

    public int buffersProcessed() {
        if (this.channelType != 1) {
            return 0;
        }
        int alGetSourcei = AL10.alGetSourcei(this.ALSource.get(0), 4118);
        if (checkALError()) {
            return 0;
        }
        return alGetSourcei;
    }

    public void flush() {
        if (this.channelType != 1) {
            return;
        }
        if (checkALError()) {
            return;
        }
        IntBuffer createIntBuffer = BufferUtils.createIntBuffer(1);
        for (int alGetSourcei = AL10.alGetSourcei(this.ALSource.get(0), 4117); alGetSourcei > 0; alGetSourcei--) {
            try {
                AL10.alSourceUnqueueBuffers(this.ALSource.get(0), createIntBuffer);
                if (checkALError()) {
                    return;
                }
            } catch (Exception e) {
                return;
            }
        }
    }

    public void close() {
        try {
            AL10.alSourceStop(this.ALSource.get(0));
            AL10.alGetError();
        } catch (Exception e) {
        }
        if (this.channelType == 1) {
            flush();
        }
    }

    public void play() {
        AL10.alSourcePlay(this.ALSource.get(0));
        checkALError();
    }

    public void pause() {
        AL10.alSourcePause(this.ALSource.get(0));
        checkALError();
    }

    public void stop() {
        AL10.alSourceStop(this.ALSource.get(0));
        checkALError();
    }

    public void rewind() {
        if (this.channelType == 1) {
            return;
        }
        AL10.alSourceRewind(this.ALSource.get(0));
        checkALError();
    }

    public boolean playing() {
        return !checkALError() && AL10.alGetSourcei(this.ALSource.get(0), 4112) == 4114;
    }

    private boolean checkALError() {
        switch (AL10.alGetError()) {
            case 0:
                return false;
            case 40961:
                errorMessage("Invalid name parameter.");
                return true;
            case 40962:
                errorMessage("Invalid parameter.");
                return true;
            case 40963:
                errorMessage("Invalid enumerated parameter value.");
                return true;
            case 40964:
                errorMessage("Illegal call.");
                return true;
            case 40965:
                errorMessage("Unable to allocate memory.");
                return true;
            default:
                errorMessage("An unrecognized error occurred.");
                return true;
        }
    }
}
